==> alg-alg-2.24.12-sources.jar: cn/com/duiba/nezha/alg/alg/vo/adx/directly/meituan/AdxDirecetlyPriceDo.java <==
package cn.com.duiba.nezha.alg.alg.vo.adx.directly.meituan;

import cn.com.duiba.nezha.alg.common.util.MathUtil;
import lombok.Data;

@Data
public class AdxDirecetlyPriceDo {

    /**
     * 广告ID
     */
    private Long advertId;

    /**
     * 素材ID
     */
    private Long materialId;

    /**
     * 计划维度设置的目标分成比例
     */
    private Double advShareRate;

    /**
     * 广告线 发券CPC价格
     */
    private Double advPrice;

    /**
     * 广告线预估 CTR
     */
    private Double ctr;

    /**
     * 广告线预估 CVR
     */
    private Double cvr;

    /**
     * 算法策略调价前的原始adx出价
     */
    private Double oriPrice; // 广告线原始出价 * 分成比例 * 维稳因子

    /**
     * 算法调整后的返回给媒体的出价
     */
    private Double adxPrice;

    /**
     * 维稳因子
     */
    private Double roiFactor;

    /**
     * CTR权重调节因子
     */
    private Double ctrFactor;

    /**
     * 新广告行业ID
     */
    private Long newTradeId;

    /**
     * 配置的真实底价(28分)，如果出价高于该底价但低于30，则以一定概率强制提价至30分
     */
    private Double realFloorPrice;

    /**
     *用户当日在美团的第3～5次竞价请求提价因子，默认1.00
     */
    private Double liftFactor; // 盘古配置的提价因子

    private double arpu; // arpu = ctr * 广告线原始cpc出价

    private double oriScore; // 原始排序分oriScore = ctr * oriPrice

    private double score; // 最终排序分score = ctr * 调整后的adx出价price

    /**
     * 是否命中cpc测试白名单，是：1，否：0
     */
    private Integer cpcTest; // cpc测试标记，是：1，否：0


    public static Double getShareRate(AdxDirecetlyPriceDo adxDirecetlyPriceDo) {
        Double ret = null;
        if(adxDirecetlyPriceDo != null && adxDirecetlyPriceDo.getAdvShareRate() != null) {
            ret = adxDirecetlyPriceDo.getAdvShareRate() /100;
        }
        return ret;
    }

    public static Double getRankScore(AdxDirecetlyPriceDo adxDirecetlyPriceDo) {
        Double ret = 0.;
        Double priceLower = 40.0;
        Double priceUpper = 80.0;
        if(adxDirecetlyPriceDo != null) {
            ret = MathUtil.dotPow(adxDirecetlyPriceDo.getAdxPrice(), adxDirecetlyPriceDo.getCtr(),
                    adxDirecetlyPriceDo.getCtrFactor(), priceLower, priceUpper, 3);
        }
        return ret;
    }

    public static Double getRankScoreRaise(AdxDirecetlyPriceDo adxDirecetlyPriceDo) {
        Double ret = 0.;
        Double priceLower = 40.0;
        Double priceUpper = 80.0;
        double adxPriceRaise = 30.1;// 从数据中分析得出的提价阈值
        double realFloorPrice = adxDirecetlyPriceDo.getRealFloorPrice();
        double adxPrice = adxDirecetlyPriceDo.getAdxPrice();
        ret = MathUtil.dotPow(adxDirecetlyPriceDo.getAdxPrice(), adxDirecetlyPriceDo.getCtr(),
                adxDirecetlyPriceDo.getCtrFactor(), priceLower, priceUpper, 3);

        // 出价介于28与30之间，则以一定概率强制提价至adxPriceRaise(30分)
        if (adxPrice < adxPriceRaise && adxPrice >= realFloorPrice) {
            adxDirecetlyPriceDo.setAdxPrice(adxPriceRaise);
        }
        return ret;
    }

}

==> alg-alg-2.24.34-sources.jar: cn/com/duiba/nezha/alg/alg/vo/adx/directly/meituan/AdxDirecetlyPriceDo.java <==
package cn.com.duiba.nezha.alg.alg.vo.adx.directly.meituan;

import cn.com.duiba.nezha.alg.common.util.MathUtil;
import lombok.Data;

import java.util.HashMap;
import java.util.Map;

@Data
public class AdxDirecetlyPriceDo {

    /**
     * 广告ID
     */
    private Long advertId;

    /**
     * 素材ID
     */
    private Long materialId;

    /**
     * 计划维度设置的目标分成比例
     */
    private Double advShareRate;

    /**
     * 广告线 发券CPC价格
     */
    private Double advPrice;

    /**
     * 广告线预估 CTR
     */
    private Double ctr;

    /**
     * 广告线预估 CVR
     */
    private Double cvr;

    /**
     * 算法策略调价前的原始adx出价
     */
    private Double oriPrice; // 广告线原始出价 * 分成比例 * 维稳因子

    /**
     * 算法调整后的返回给媒体的出价
     */
    private Double adxPrice;

    /**
     * 维稳因子
     */
    private Double roiFactor;

    /**
     * CTR权重调节因子
     */
    private Double ctrFactor;

    /**
     * 新广告行业ID
     */
    private Long newTradeId;

    /**
     * 配置的真实底价(28分)，如果出价高于该底价但低于30，则以一定概率强制提价至30分
     */
    private Double realFloorPrice;

    /**
     *用户当日在美团的第3～5次竞价请求提价因子，默认1.00
     */
    private Double liftFactor; // 盘古配置的提价因子

    private double arpu; // arpu = ctr * 广告线原始cpc出价

    private double oriScore; // 原始排序分oriScore = ctr * oriPrice

    private double score; // 最终排序分score = ctr * 调整后的adx出价price

    /**
     * 是否命中cpc测试白名单，是：1，否：0
     */
    private Integer cpcTest; // cpc测试标记，是：1，否：0

    /**
     * 探价因子表({分组：小数})
     * 初始化：{"1": 1.0, "2": 1.5, "3": 2.0, "4": 2.5, "5": 3.0}
     */
    private Map<String, Double> factorExploreMap = new HashMap<>();

    /**
     * 探价id
     */
    private Long exploreId;

    /**
     * 探价分桶标记
     */
    private Integer level;

    /**
     * 探价因子
     */
    private double priceFactor;


    public static Double getShareRate(AdxDirecetlyPriceDo adxDirecetlyPriceDo) {
        Double ret = null;
        if(adxDirecetlyPriceDo != null && adxDirecetlyPriceDo.getAdvShareRate() != null) {
            ret = adxDirecetlyPriceDo.getAdvShareRate() /100;
        }
        return ret;
    }

    public static Double getRankScore(AdxDirecetlyPriceDo adxDirecetlyPriceDo) {
        Double ret = 0.;
        Double priceLower = 40.0;
        Double priceUpper = 80.0;
        if(adxDirecetlyPriceDo != null) {
            ret = MathUtil.dotPow(adxDirecetlyPriceDo.getAdxPrice(), adxDirecetlyPriceDo.getCtr(),
                    adxDirecetlyPriceDo.getCtrFactor(), priceLower, priceUpper, 3);
        }
        return ret;
    }

    public static Double getRankScoreRaise(AdxDirecetlyPriceDo adxDirecetlyPriceDo) {
        Double ret = 0.;
        Double priceLower = 40.0;
        Double priceUpper = 80.0;
        double adxPriceRaise = 30.1;// 从数据中分析得出的提价阈值
        double realFloorPrice = adxDirecetlyPriceDo.getRealFloorPrice();
        double adxPrice = adxDirecetlyPriceDo.getAdxPrice();
        ret = MathUtil.dotPow(adxDirecetlyPriceDo.getAdxPrice(), adxDirecetlyPriceDo.getCtr(),
                adxDirecetlyPriceDo.getCtrFactor(), priceLower, priceUpper, 3);

        // 出价介于28与30之间，则以一定概率强制提价至adxPriceRaise(30分)
        if (adxPrice < adxPriceRaise && adxPrice >= realFloorPrice) {
            adxDirecetlyPriceDo.setAdxPrice(adxPriceRaise);
        }
        return ret;
    }

}
